@@ -191,7 +191,7 @@ Kolf::RectangleItem::RectangleItem(const QString& type, QGraphicsItem* parent, b
 	, CanvasItem(world)
 	, m_wallPen(QColor("#92772D").darker(), 3)
 	, m_wallAllowed(Kolf::RectangleWallCount, true)
-	, m_walls(Kolf::RectangleWallCount, 0)
+	, m_walls(Kolf::RectangleWallCount, nullptr)
 	, m_shape(new Kolf::RectShape(QRectF(0, 0, 1, 1)))
 {
 	addShape(m_shape);
@@ -232,10 +232,10 @@ void Kolf::RectangleItem::setWall(Kolf::WallIndex index, bool hasWall)
 	else
 	{
 		delete m_walls[index];
-		m_walls[index] = 0;
+		m_walls[index] = nullptr;
 	}
 	propagateUpdate();
-	emit wallChanged(index, hasWall, m_wallAllowed[index]);
+	Q_EMIT wallChanged(index, hasWall, m_wallAllowed[index]);
 }
 
 void Kolf::RectangleItem::setWallAllowed(Kolf::WallIndex index, bool wallAllowed)
@@ -244,7 +244,7 @@ void Kolf::RectangleItem::setWallAllowed(Kolf::WallIndex index, bool wallAllowed
 	//delete wall if one exists at this position currently
 	if (!wallAllowed)
 		setWall(index, false);
-	emit wallChanged(index, hasWall(index), wallAllowed);
+	Q_EMIT wallChanged(index, hasWall(index), wallAllowed);
 }
 
 void Kolf::RectangleItem::updateWallPosition()
@@ -282,13 +282,13 @@ void Kolf::RectangleItem::moveBy(double dx, double dy)
 	Tagaro::SpriteObjectItem::moveBy(dx, dy);
 	//move myself
 	const QPointF pos = this->pos();
-	foreach (Kolf::Wall* wall, m_walls)
+	for (Kolf::Wall* wall : qAsConst(m_walls))
 		if (wall)
 			wall->setPos(pos);
 	//update Z order
 	CanvasItem::moveBy(dx, dy);
-	foreach (QGraphicsItem* qitem, collidingItems())
-	{
+	const auto collidingItems = this->collidingItems();
+	for (QGraphicsItem* qitem : collidingItems) {
 		CanvasItem* citem = dynamic_cast<CanvasItem*>(qitem);
 		if (citem)
 			citem->updateZ(qitem);
@@ -298,7 +298,7 @@ void Kolf::RectangleItem::moveBy(double dx, double dy)
 void Kolf::RectangleItem::setWallColor(const QColor& color)
 {
 	m_wallPen = QPen(color.darker(), 3);
-	foreach (Kolf::Wall* wall, m_walls)
+	for (Kolf::Wall* wall : qAsConst(m_walls))
 		applyWallStyle(wall);
 }
 
@@ -402,7 +402,7 @@ void Kolf::RectangleOverlay::moveHandle(const QPointF& handleScenePos)
 Kolf::RectangleConfig::RectangleConfig(Kolf::RectangleItem* item, QWidget* parent)
 	: Config(parent)
 	, m_layout(new QGridLayout(this))
-	, m_wallCheckBoxes(Kolf::RectangleWallCount, 0)
+	, m_wallCheckBoxes(Kolf::RectangleWallCount, nullptr)
 	, m_item(item)
 {
 	static const char* captions[] = { I18N_NOOP("&Top"), I18N_NOOP("&Left"), I18N_NOOP("&Right"), I18N_NOOP("&Bottom") };
